@@ -12,12 +12,16 @@ private:
     unsigned int num_taxa_;
     unsigned int num_char_;
     unsigned int num_retained_;
+    unsigned int min_chars_per_site_;
+    unsigned int max_missing_;
     double missing_allowed_;
     
     bool by_taxon_;
     bool by_codon_;
     bool count_only_;
     bool verbose_;
+    bool remove_empty_;
+    bool min_chars_;
     
     std::string badChars_;
     std::string alpha_name_;
@@ -39,8 +43,8 @@ private:
     void set_bad_chars ();
 
 public:
-    SequenceCleaner (std::istream* pios, double& prop_required,
-        const bool& by_taxon, const bool& by_codon, const bool& count_only,
+    SequenceCleaner (std::istream* pios, double& prop_required, const bool& remove_empty,
+        const int& min_chars, const bool& by_taxon, const bool& by_codon, const bool& count_only,
         const bool& verbose);
     std::vector<Sequence> get_cleaned_seqs () const; // not used, but available
     void write_seqs (std::ostream* poos);
