@@ -44,8 +44,8 @@ void print_help () {
 }
 
  std::string get_version_line () {
-    std::string vl = "pxbdsim 1.3\n";
-    vl += "Copyright (C) 2013-2021 FePhyFoFum\n";
+    std::string vl = "pxbdsim 1.3.1\n";
+    vl += "Copyright (C) 2013-2024 FePhyFoFum\n";
     vl += "License GPLv3\n";
     vl += "Written by Stephen A. Smith (blackrim), Joseph W. Brown";
     return vl;
