@@ -43,8 +43,8 @@ void print_help () {
 }
 
 std::string get_version_line () {
-    std::string vl = "pxmono 1.3\n";
-    vl += "Copyright (C) 2019-2021 FePhyFoFum\n";
+    std::string vl = "pxmono 1.3.1\n";
+    vl += "Copyright (C) 2019-2024 FePhyFoFum\n";
     vl += "License GPLv3\n";
     vl += "Written by Joseph W. Brown";
     return vl;
