@@ -41,8 +41,8 @@ void print_help () {
 }
 
 std::string get_version_line () {
-    std::string vl = "pxrms 1.3\n";
-    vl += "Copyright (C) 2015-2021 FePhyFoFum\n";
+    std::string vl = "pxrms 1.3.1\n";
+    vl += "Copyright (C) 2015-2024 FePhyFoFum\n";
     vl += "License GPLv3\n";
     vl += "Written by Joseph W. Brown, Joseph F. Walker, Stephen A. Smith (blackrim)";
     return vl;
