@@ -53,8 +53,8 @@ void print_help () {
 }
 
 std::string get_version_line () {
-    std::string vl = "pxstrec 1.3\n";
-    vl += "Copyright (C) 2017-2021 FePhyFoFum\n";
+    std::string vl = "pxstrec 1.3.1\n";
+    vl += "Copyright (C) 2017-2024 FePhyFoFum\n";
     vl += "License GPLv3\n";
     vl += "Written by Stephen A. Smith (blackrim)";
     return vl;
