@@ -36,8 +36,8 @@ void print_help () {
 }
 
 std::string get_version_line () {
-    std::string vl = "pxt2nex 1.3\n";
-    vl += "Copyright (C) 2021-2021 FePhyFoFum\n";
+    std::string vl = "pxt2nex 1.3.1\n";
+    vl += "Copyright (C) 2021-2024 FePhyFoFum\n";
     vl += "License GPLv3\n";
     vl += "Written by Joseph W. Brown, Stephen A. Smith (blackrim)";
     return vl;
