@@ -427,10 +427,10 @@ bool is_prot_char (char& residue) {
 }
 
 
-// ignore ambiguity codes
+// ignore ambiguity codes. include N for seqs that use N instead of ? or -
 int count_dna_chars (const std::string& str) {
     int ndna = 0;
-    std::string dnaChars = "ACGT";
+    std::string dnaChars = "ACGTN";
     for (char dnaChar : dnaChars) {
         ndna += std::count(str.begin(), str.end(), dnaChar);
     }
@@ -471,6 +471,23 @@ bool is_codon_alignment (const std::vector<Sequence>& seqs) {
 }
 
 
+// looking for TAG, TGA, TAA, at least until alien DNA is decoded
+bool is_stop_terminated (std::string& seq) {
+    bool stop = false;
+    
+    // convert to uppercase for weirdo Nat files :)
+    std::string tester = string_to_upper(seq);
+    
+    if (ends_with(tester, "TAG")) {
+        stop = true;
+    } else if (ends_with(tester, "TGA")) {
+        stop = true;
+    } else if (ends_with(tester, "TAA")) {
+        stop = true;
+    }
+    return stop;
+}
+
 // these are not currently used
 /*
 void populate_codon_list (std::vector<std::string> * codon_list) {
